==> haskell-insert-ordered-containers-0.2.5.3-165-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 insert-ordered-containers
version:              0.2.5.3
visibility:           public
id:                   insert-ordered-containers-0.2.5.3-1vMS0zgZAhREdKpjP2hLv
key:                  insert-ordered-containers-0.2.5.3-1vMS0zgZAhREdKpjP2hLv
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/insert-ordered-containers#readme
synopsis:
    Associative containers retaining insertion order for traversals.

description:
    Associative containers retaining insertion order for traversals.

    The implementation is based on `unordered-containers`.

category:             Web
abi:                  2b868ce1e55626b84a35b58b2651fb8d
exposed:              True
exposed-modules:      Data.HashMap.Strict.InsOrd Data.HashSet.InsOrd
hidden-modules:       Data.HashMap.InsOrd.Internal
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-insert-ordered-containers
hs-libraries:         HSinsert-ordered-containers-0.2.5.3-1vMS0zgZAhREdKpjP2hLv
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    indexed-traversable-0.1.4-EeVo0prc4Ve5Oh8yIcLoq0
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR
    optics-core-0.4.1.1-KepOO2XhGiVI9ebd7nfRdE
    optics-extra-0.4.2.1-LCBbL4xhvXB2EWRjkaQ4RH
    semigroupoids-6.0.1-6I5b3GpOwhwAglmgd4w9RR text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk

haddock-interfaces:
    /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-insert-ordered-containers-0.2.5.3-188-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 insert-ordered-containers
version:              0.2.5.3
visibility:           public
id:                   insert-ordered-containers-0.2.5.3-4jsGq1TPuGQ576igjgghvC
key:                  insert-ordered-containers-0.2.5.3-4jsGq1TPuGQ576igjgghvC
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/insert-ordered-containers#readme
synopsis:
    Associative containers retaining insertion order for traversals.

description:
    Associative containers retaining insertion order for traversals.

    The implementation is based on `unordered-containers`.

category:             Web
abi:                  d5e2ce92390777f0eb4941d6932da829
exposed:              True
exposed-modules:      Data.HashMap.Strict.InsOrd Data.HashSet.InsOrd
hidden-modules:       Data.HashMap.InsOrd.Internal
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-insert-ordered-containers
hs-libraries:         HSinsert-ordered-containers-0.2.5.3-4jsGq1TPuGQ576igjgghvC
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    indexed-traversable-0.1.4-KvS9wRlCKDWFRGYTEgz6lC
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb
    optics-core-0.4.1.1-BGa8jf2OfyC93qUm2sUAis
    optics-extra-0.4.2.1-9Cny1ifpaD85rifAzUmYq
    semigroupoids-6.0.1-Bxz0f1JNfGSLvZg0Ig0I9J text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM

haddock-interfaces:
    /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
